html {
  height: 100%;
}

body {
  background-color: #f5fffa;
  height: 100%;
}

.wrapper {
  width: 100%;
  height: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
}
.wrapper .file-upload {
  height: 200px;
  width: 200px;
  border-radius: 100px;
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  border: 4px solid #000000;
  overflow: hidden;
  background-image: linear-gradient(to bottom, #f5fffa 50%, #000000 50%);
  background-size: 100% 200%;
  transition: all 1s;
  color: #000000;
  font-size: 100px;
}
.wrapper .file-upload input[type="file"] {
  height: 200px;
  width: 200px;
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0;
  cursor: pointer;
}
.wrapper .file-upload:hover {
  background-position: 0 -100%;
  color: #f5fffa;
}
.full_screen {
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
}
